<?xml version="1.0" encoding="utf-8"?>

<!-- Original Spanish translation done by chroma_ghost & bazza/pixls.us -->

<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="168"/>
        <source>Select color</source>
        <translation>Seleccionar color</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="221"/>
        <source>Internet updates</source>
        <translation>Actualizaciones de internet</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="230"/>
        <source>Update now</source>
        <translation>Actualizar ahora</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>Disposición</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>Previsualizar a la &amp;izquierda</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>Previsualizar a la &amp;derecha</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>&amp;Valor predeterminado</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>&amp;Oscuro</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(Reinicio necesario)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="215"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="253"/>
        <location filename="../src/DialogSettings.cpp" line="84"/>
        <source>Output messages</source>
        <translation>Mensages de salida</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Dialogs</source>
        <translation>Diálogos</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>Use native color dialog</source>
        <translation>Usar color nativo en los diálogos</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation type="unfinished">Previsualización</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="262"/>
        <source>Notify when scheduled update fails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="304"/>
        <source>&amp;Ok</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="64"/>
        <source>Settings</source>
        <translation>Parámetros</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="70"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="71"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="72"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="73"/>
        <source>Every 2 weeks</source>
        <translation>Cada 2 semanas</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="74"/>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="76"/>
        <source>At launch (debug)</source>
        <translation>Al iniciar (depurar)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="85"/>
        <source>Quiet (default)</source>
        <translation>Silencioso (por defecto)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="86"/>
        <source>Verbose (console)</source>
        <translation>Modo verborraico (consola)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="87"/>
        <source>Verbose (log file)</source>
        <translation>Modo verborraico (archivo de registro)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Very verbose (console)</source>
        <translation>Modo muy verborraico (consola)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="89"/>
        <source>Very verbose (log file)</source>
        <translation>Modo muy verborraico (archivo de registro)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Debug (console)</source>
        <translation>Depurar errores (consola)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="91"/>
        <source>Debug (log file)</source>
        <translation>Depurar errores (archivo de registro)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="107"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>Seleccionar para usar el diálogo de color nativo/SO,  deseleccionar para usar el de Qt</translation>
    </message>
</context>
<context>
    <name>FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="149"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="152"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="155"/>
        <source>Select a file</source>
        <translation>Seleccionar un archivo</translation>
    </message>
</context>
<context>
    <name>FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="39"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="172"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation type="unfinished">&lt;i&gt;Seleccionar un filtro&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="139"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation type="unfinished">&lt;i&gt;Sin parámetros&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="144"/>
        <source>Error parsing filter parameters

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="339"/>
        <source>Unknown filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="427"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished">GMIC</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="65"/>
        <source>Rename fave</source>
        <translation type="unfinished">Renombrar un favorito</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="67"/>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="344"/>
        <source>Remove fave</source>
        <translation type="unfinished">Eliminar un favorito</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="69"/>
        <source>Clone fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="73"/>
        <source>Add fave</source>
        <translation type="unfinished">Adicionar un favorito</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="345"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="127"/>
        <source>Select a folder</source>
        <translation>Seleccionar una carpeta</translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="271"/>
        <source>Input / Output</source>
        <translation>Entrada / Salida</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="102"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="72"/>
        <source>Input layers</source>
        <translation>Capas de entrada</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="138"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="95"/>
        <source>Output mode</source>
        <translation>Modo de salida</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="125"/>
        <location filename="../src/Widgets/InOutPanel.cpp" line="111"/>
        <source>Preview mode</source>
        <translation>Modo previsualización</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="273"/>
        <source>Input / Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="273"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="275"/>
        <source>Output / Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="275"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished">GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="38"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(Reinicio necesario)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="48"/>
        <source>System default (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="161"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Descargar las definiciones del filtro de fuentes remotas&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="164"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="128"/>
        <source>Selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="496"/>
        <source>TextLabel</source>
        <translation>Etiqueta de Texto</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="233"/>
        <location filename="../ui/mainwindow.ui" line="240"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="386"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="389"/>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="480"/>
        <source>Settings...</source>
        <translation>Parámetros...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="509"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="522"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="535"/>
        <source>&amp;Apply</source>
        <translation>&amp;Aplicar</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="548"/>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="102"/>
        <source>Add fave</source>
        <translation>Adicionar un favorito</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="104"/>
        <source>Reset parameters to default values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="110"/>
        <source>Copy G&apos;MIC command to clipboard</source>
        <translation>Copiar el comando G&apos;MIC al portapapeles</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>Update filters</source>
        <translation>Actualizar filtros</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Rename fave</source>
        <translation>Renombrar un favorito</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="115"/>
        <source>Remove fave</source>
        <translation>Eliminar un favorito</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <source>Expand/Collapse all</source>
        <translation>Expandir/Colapsar todos</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="121"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Universidad de Normandía (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="329"/>
        <source>Update completed</source>
        <translation>Actualización completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="329"/>
        <location filename="../src/MainWindow.cpp" line="331"/>
        <location filename="../src/MainWindow.cpp" line="385"/>
        <source>Filter definitions have been updated.</source>
        <translation>Las definiciones de filtros han sido actualizadas.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="334"/>
        <source>No download was needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="381"/>
        <source>Filters update could not be achieved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="503"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>La actualización no ha sido posible&lt;br&gt; debido a los siguientes errores :&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="509"/>
        <source>Update error</source>
        <translation>Error en la actualización</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="711"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="807"/>
        <source>Waiting for cancelled jobs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1169"/>
        <source>Import faves</source>
        <translation>Importar favoritos</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1169"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>¿Quieres importar favoritos del archivo de abajo?&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1172"/>
        <source>Don&apos;t ask again</source>
        <translation>No volver a preguntar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1284"/>
        <source>Confirmation</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1284"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>Se está ejecutando un comando de gmic.&apos;exÃ©cution.&lt;br&gt;¿Seguro que quieres cerrar el plugin?</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="38"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Enter</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>Etiqueta de texto</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="46"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="147"/>
        <source>Updating filters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="202"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="215"/>
        <source>[Processing %1 | %2]</source>
        <translation>[Procesando %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="217"/>
        <source>[Processing %1]</source>
        <translation>[Procesando %1]</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ventana Principal</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation>Etiqueta de Texto</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="138"/>
        <source>%1 seconds</source>
        <translation>%1 segundos</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="148"/>
        <source>[Processing %1 | %2]</source>
        <translation>[Procesando %1 | %2]</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="150"/>
        <source>[Processing %1]</source>
        <translation>[Procesando %1]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="68"/>
        <source>Select an image to open...</source>
        <translation>Seleccionar una imagen para abrir...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="68"/>
        <source>PNG &amp; JPG files (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</source>
        <translation>Archivos PNG &amp; JPG (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="78"/>
        <source>Default image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="88"/>
        <source>Visible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="86"/>
        <source>Available filters (%1)</source>
        <translation>Filtros disponibles (%1)</translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Marco</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="76"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="77"/>
        <source>Search in filters list (%1)</source>
        <translation>Buscar en la lista de filtros (%1)</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="204"/>
        <source>Could not read/decompress %1</source>
        <translation>Impossible de leer/descomprimir %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="195"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>Error al descargar %1 (archivo vacío?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="210"/>
        <source>Error creating file %1</source>
        <translation>Error en la creación del archivo %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="214"/>
        <source>Error writing file %1</source>
        <translation>Error al escribir el archivo %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="231"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="264"/>
        <source>Download timeout: %1</source>
        <translation>Descarga anulada (tiempo límite) : %1</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation type="unfinished">GMIC</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="51"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="52"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
        <source>Reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="153"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
